@@ -1,5 +1,3 @@
-#[cfg(all(unix, feature = "with_x11"))]
-mod debounce;
 mod error;
 #[cfg(all(unix, not(feature = "with_x11")))]
 mod unix_none;
@@ -7,6 +5,8 @@ mod unix_x11;
 #[cfg(windows)]
 mod windows;
 
+use crate::api::ClipboardProviding;
+
 pub use self::error::*;
 #[cfg(all(unix, not(feature = "with_x11")))]
 pub use self::unix_none::Clipboard;
@@ -16,7 +16,9 @@ pub use self::unix_x11::Clipboard;
 pub use self::windows::Clipboard;
 
 pub trait SelectionProvider: Send + Sync {
-  fn current_selection_name(&self) -> Option<String>;
+  fn current_selection(&self) -> Option<ClipboardProviding>;
 
-  fn get_selection(&mut self) -> Option<String>;
+  fn get_selection_value(&self) -> Option<String>;
+
+  fn next_selection(&mut self);
 }
